@@ -23,12 +23,16 @@
 #'
 #' @export
 #' @examples
-#' tmpdir <- tempdir()
+#' tmpdir <- tempfile(pattern = "description")
+#' dir.create(tmpdir)
 #' file.copy(system.file("dummypackage",package = "attachment"), tmpdir,
 #'  recursive = TRUE)
 #' dummypackage <- file.path(tmpdir, "dummypackage")
 #' # browseURL(dummypackage)
-#' att_amend_desc(path = dummypackage)
+#' att_amend_desc(path = tmpdir)
+#'
+#' # Clean after examples
+#' unlink(tmpdir, recursive = TRUE)
 
 att_amend_desc <- function(path = ".",
                            path.n = "NAMESPACE",
@@ -41,7 +45,8 @@ att_amend_desc <- function(path = ".",
                            document = TRUE,
                            normalize = TRUE,
                            inside_rmd = FALSE,
-                           must.exist = TRUE
+                           must.exist = TRUE,
+                           check_if_suggests_is_installed = TRUE
 ) {
 
 
@@ -159,7 +164,7 @@ att_amend_desc <- function(path = ".",
   suggests <- suggests[suggests != "base"]
 
   # Build DESCRIPTION ----
-  att_to_desc_from_is(path.d, imports, suggests, normalize, must.exist)
+  att_to_desc_from_is(path.d, imports, suggests, normalize, must.exist, check_if_suggests_is_installed = check_if_suggests_is_installed)
 }
 
 #' @rdname att_amend_desc
@@ -171,6 +176,7 @@ att_to_desc_from_pkg <- att_amend_desc
 #' @param path.d path to description file.
 #' @param imports character vector of package names to add in Imports section
 #' @param suggests character vector of package names to add in Suggests section
+#' @param check_if_suggests_is_installed Logical. Whether to require that packages in the Suggests section are installed.
 #' @param normalize Logical. Whether to normalize the DESCRIPTION file. See [desc::desc_normalize()]
 #' @param must.exist Logical. If TRUE then an error is given if packages do not exist
 #' within installed packages. If NA, a warning.
@@ -190,20 +196,25 @@ att_to_desc_from_pkg <- att_amend_desc
 #' you may want to set to `FALSE` (no message at all) or `NA` (warning for not installed).
 #'
 #' @examples
-#' tmpdir <- tempdir()
+#' tmpdir <- tempfile(pattern = "descfromis")
+#' dir.create(tmpdir)
 #' file.copy(system.file("dummypackage",package = "attachment"), tmpdir,
 #'  recursive = TRUE)
 #' dummypackage <- file.path(tmpdir, "dummypackage")
 #' # browseURL(dummypackage)
 #' att_to_desc_from_is(path.d = file.path(dummypackage, "DESCRIPTION"),
 #' imports = c("magrittr", "attachment"), suggests = c("knitr"))
+#'
 #' # In combination with other functions
 #' att_to_desc_from_is(path.d = file.path(dummypackage, "DESCRIPTION"),
 #' imports = att_from_rscripts(file.path(dummypackage, "R")),
 #' suggests = att_from_rmds(file.path(dummypackage, "vignettes")))
+#'
+#' # Clean temp files after this example
+#' unlink(tmpdir, recursive = TRUE)
 
 att_to_desc_from_is <- function(path.d = "DESCRIPTION", imports = NULL,
-                                suggests = NULL, normalize = TRUE,
+                                suggests = NULL, check_if_suggests_is_installed = TRUE, normalize = TRUE,
                                 must.exist = TRUE) {
 
   if (!file.exists(path.d)) {
@@ -226,9 +237,13 @@ att_to_desc_from_is <- function(path.d = "DESCRIPTION", imports = NULL,
 
   # rlang::check_installed("pkg")
   # imports
+  check_installed <- c(imports)
+  if (check_if_suggests_is_installed){
+    check_installed <- c(check_installed, suggests)
+  }
   suppressWarnings(
     res <- vapply(
-      c(imports, suggests), FUN = requireNamespace,
+      check_installed, FUN = requireNamespace,
       FUN.VALUE = logical(1), quietly = TRUE)
   )
   missing_packages <- names(res[!res])
