@@ -61,13 +61,18 @@ find_remotes <- function(pkg) {
 #' @return Used for side effect. Adds Remotes field in DESCRIPTION file.
 #' @export
 #' @examples
-#' tmpdir <- tempdir()
+#' tmpdir <- tempfile(pattern = "setremotes")
+#' dir.create(tmpdir)
 #' file.copy(system.file("dummypackage", package = "attachment"), tmpdir,
 #'  recursive = TRUE)
 #' dummypackage <- file.path(tmpdir, "dummypackage")
 #' # Add remotes field if there are Remotes locally
 #' att_amend_desc(dummypackage) %>%
 #'   set_remotes_to_desc()
+#'
+#' # Clean temp files after this example
+#' unlink(tmpdir, recursive = TRUE)
+#'
 #' \dontrun{
 #' # For your current package
 #' att_amend_desc() %>%
@@ -155,7 +160,7 @@ internal_remotes_to_desc <- function(remotes, path.d = "DESCRIPTION",
 #' @noRd
 extract_pkg_info <- function(pkgdesc) {
   is_cran <- lapply(pkgdesc, function(x) {
-    !is.null(x[["Repository"]]) |
+    (!is.null(x[["Repository"]]) && !grepl("r-universe", x[["Repository"]])) |
       (!is.null(x[["Priority"]]) && x[["Priority"]] == "base")
   }) %>% unlist()
 
@@ -167,12 +172,16 @@ extract_pkg_info <- function(pkgdesc) {
   } else {
     guess_repo <- lapply(pkg_not_cran, function(x) {
       desc <- pkgdesc[[x]]
-      if (!is.null(desc$RemoteType) && desc$RemoteType == "github") {
+      if (!is.null(desc[["Repository"]]) && grepl("r-universe", desc[["Repository"]])) {
+        # For when {remotes} and/or {pak} can read universe from Remotes: field ?
+        # paste0("universe::", gsub(".r-universe.dev", "", desc[["Repository"]]), "/", desc[["Package"]])
+        setNames(NA, paste0("r-universe: need to set options to repos=\"", desc[["Repository"]], "\""))
+      } else if (!is.null(desc$RemoteType) && desc$RemoteType == "github") {
         paste(desc$RemoteUsername, desc$RemoteRepo, sep = "/")
       } else if (!is.null(desc$RemoteType) && desc$RemoteType %in% c("gitlab", "bitbucket")) {
         paste0(desc$RemoteType, "::",
                        paste(desc$RemoteUsername, desc$RemoteRepo, sep = "/"))
-      } else if (desc$RemoteType == "local" && !is.null(desc$RemoteUrl)  && is.null(desc$RemoteHost)) {
+      } else if (!is.null(desc$RemoteType) && desc$RemoteType == "local" && !is.null(desc$RemoteUrl)  && is.null(desc$RemoteHost)) {
         paste0(desc$RemoteType, "::", desc$RemoteUrl)
       } else if (!is.null(desc$RemoteType) &&
                  !(desc$RemoteType %in% c("github","gitlab","bitbucket","local")) &&
