@@ -1,6 +1,6 @@
 # att_amend_desc ----
 # Copy package in a temporary directory
-tmpdir <- tempfile("dummy")
+tmpdir <- tempfile("dummyamend")
 dir.create(tmpdir)
 file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
 dummypackage <- file.path(tmpdir, "dummypackage")
@@ -36,7 +36,7 @@ test_that("att_amend_desc updates description", {
 unlink(dummypackage, recursive = TRUE)
 
 # Remotes stays here if exists ----
-tmpdir <- tempfile("dummy")
+tmpdir <- tempfile("dummyremotes")
 dir.create(tmpdir)
 file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
 dummypackage <- file.path(tmpdir, "dummypackage")
@@ -63,7 +63,7 @@ test_that("Remotes stays here if exists and package in imports/suggests", {
 unlink(dummypackage, recursive = TRUE)
 
 # pkg_ignore and extra.suggests are used ----
-tmpdir <- tempfile("dummy")
+tmpdir <- tempfile("dummyextra")
 dir.create(tmpdir)
 file.copy(system.file("dummypackage", package = "attachment"), tmpdir, recursive = TRUE)
 dummypackage <- file.path(tmpdir, "dummypackage")
@@ -86,7 +86,7 @@ test_that("pkg_ignore and extra.suggests are used", {
 unlink(dummypackage, recursive = TRUE)
 
 # Test fails if dir.t do not exists
-tmpdir <- tempfile("dummy")
+tmpdir <- tempfile("dummydirt")
 dir.create(tmpdir)
 file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
 dummypackage <- file.path(tmpdir, "dummypackage")
@@ -127,7 +127,8 @@ unlink(dummypackage, recursive = TRUE)
 # Test Deprecated att_to_description ----
 # suppressWarnings()
 # Copy package in a temporary directory
-tmpdir <- tempdir()
+tmpdir <- tempfile(pattern = "deprecated")
+dir.create(tmpdir)
 file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
 dummypackage <- file.path(tmpdir, "dummypackage")
 # browseURL(dummypackage)
@@ -138,12 +139,13 @@ namespace_file <- readLines(file.path(tmpdir, "dummypackage", "NAMESPACE"))
 test_that("att_to_description still updates namespace", {
   expect_length(namespace_file, 4)
 })
-unlink(dummypackage, recursive = TRUE)
+unlink(tmpdir, recursive = TRUE)
 
 
 # att_to_desc_from_is ----
 # Copy package in a temporary directory
-tmpdir <- tempdir()
+tmpdir <- tempfile(pattern = "pkg")
+dir.create(tmpdir)
 file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
 dummypackage <- file.path(tmpdir, "dummypackage")
 # browseURL(dummypackage)
@@ -166,13 +168,13 @@ test_that("att_to_desc_from_is updates description", {
   expect_equal(desc_file[w.depends + 7], "LinkingTo:" )
   expect_equal(desc_file[w.depends + 8], "    Rcpp")
 })
-unlink(dummypackage, recursive = TRUE)
+unlink(tmpdir, recursive = TRUE)
 
 
 
 # Test missing DESCRIPTION works ----
 # Copy package in a temporary directory
-tmpdir <- tempfile("dummy")
+tmpdir <- tempfile("dummydesc")
 dir.create(tmpdir)
 file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
 dummypackage <- file.path(tmpdir, "dummypackage")
@@ -196,9 +198,11 @@ test_that("Works with missing DESCRIPTION", {
   expect_false(any(grepl("dummypackage", desc_file[-1])))
 })
 
+unlink(tmpdir, recursive = TRUE)
+
 # Test missing NAMESPACE works ----
 # Copy package in a temporary directory
-tmpdir <- tempfile("dummy")
+tmpdir <- tempfile("dummyname")
 dir.create(tmpdir)
 file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
 dummypackage <- file.path(tmpdir, "dummypackage")
@@ -217,12 +221,13 @@ test_that("Works with missing DESCRIPTION", {
 
 })
 
+unlink(tmpdir, recursive = TRUE)
 # Note: glue is necessary for {attachment}, ggplot2 is not even in suggests.
 
 # missing pkg in R is not installed ----
 test_that("missing pkg is not installed", {
   # Copy package in a temporary directory
-  tmpdir <- tempfile("dummy")
+  tmpdir <- tempfile("dummymissing")
   dir.create(tmpdir)
   file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
   dummypackage <- file.path(tmpdir, "dummypackage")
@@ -246,14 +251,14 @@ ggplot() +
   # "The package ggplot is missing or misspelled.")
 
   # Clean after
-  unlink(dummypackage)
+  unlink(dummypackage, recursive = TRUE)
 })
 
 # missing pkgS are not installed ----
 test_that("missing pkgS are not installed", {
 
   # Copy package in a temporary directory
-  tmpdir <- tempfile("dummy")
+  tmpdir <- tempfile("dummypkgs")
   dir.create(tmpdir)
   file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
   dummypackage <- file.path(tmpdir, "dummypackage")
@@ -278,13 +283,13 @@ ggplot() +
   # "Packages ggplot & ggplot3 are missing or misspelled.")
 
   # Clean after
-  unlink(dummypackage)
+  unlink(dummypackage, recursive = TRUE)
 })
 
 # missing pkg in vignette (Suggests) is not installed ----
 test_that("missing pkg is not installed", {
   # Copy package in a temporary directory
-  tmpdir <- tempfile("dummy")
+  tmpdir <- tempfile("dummysuggestinstal")
   dir.create(tmpdir)
   file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
   dummypackage <- file.path(tmpdir, "dummypackage")
@@ -298,11 +303,10 @@ library(ggplot3)
 ```
 ", file = file.path(dummypackage, "vignettes", "vignette.Rmd"))
 
-  expect_error(attachment::att_amend_desc(path = dummypackage),
+  expect_error(attachment::att_amend_desc(path = dummypackage,check_if_suggests_is_installed = TRUE),
                "The package ggplot3 is missing or misspelled.")
-
   # Clean after
-  unlink(dummypackage)
+  unlink(dummypackage, recursive = TRUE)
 })
 
 # Test update desc when missing packages for books ----
@@ -364,6 +368,15 @@ if (interactive()) {
   #     open = FALSE,
   #   )
   # )
+
+  answer <- rstudioapi::showQuestion(
+    "Run interactive test?",
+    paste("Do you want to open a new RStudio session for the test?\n",
+          "If yes, you will have to run: source('dev/test_to_run.R')"),
+    cancel = "no", ok = "yes")
+
+  if (isTRUE(answer)) {
+
   tmpdir <- tempfile("manual")
   dir.create(tmpdir)
   file.copy(system.file("dummypackage",package = "attachment"),
@@ -393,18 +406,67 @@ my_length <- function(x) {
 # This should work without error
 my_length(1)
 
+
 "),
     con = file.path(dummypackage, "dev", "test_to_run.R")
   )
 
-  answer <- rstudioapi::showQuestion(
-    "Run interactive test?",
-    paste("Do you want to open a new RStudio session for the test?\n",
-          "If yes, you will have to run: source('dev/test_to_run.R')"))
-
-  if (answer) {
     rstudioapi::openProject(path = dummypackage, newSession = TRUE)
+
+    answer2 <- rstudioapi::showQuestion(
+      "Did the code in 'dev/test_to_run.R' worked correctly ?",
+      paste("Did the code in 'dev/test_to_run.R' worked correctly ?",
+      "\n\n(You can close the RStudio session opened, the project will be deleted)"),
+      cancel = "no", ok = "yes")
+
+    test_that("if check_if_suggests_is_installed = FALSE no test is done on Suggests packages", {
+      expect_true(answer2)
+    })
+
+    unlink(tmpdir, recursive = TRUE)
+
   }
 
 
 }
+
+
+# missing pkg in vignette (Suggests) is not installed but we dont check it ----
+test_that("if check_if_suggests_is_installed = FALSE no test is done on Suggests packages", {
+  # Copy package in a temporary directory
+  tmpdir <- tempfile("dummysuggestcheck")
+  dir.create(tmpdir)
+  file.copy(system.file("dummypackage",package = "attachment"), tmpdir, recursive = TRUE)
+  dummypackage <- file.path(tmpdir, "dummypackage")
+  # browseURL(dummypackage)
+  cat("
+## The vignette
+```{r}
+library(glue)
+library(ggplot3)
+```
+", file = file.path(dummypackage, "vignettes", "vignette.Rmd"))
+  attachment::att_amend_desc(path = dummypackage,check_if_suggests_is_installed = FALSE)
+
+
+  desc_file <- readLines(file.path(dummypackage, "DESCRIPTION"))
+
+  w.depends <- grep("Depends:", desc_file)
+  expect_length(w.depends, 1)
+  expect_equal(desc_file[w.depends + 1], "    R (>= 3.5.0)")
+  expect_equal(desc_file[w.depends + 2], "Imports: ")
+  expect_equal(desc_file[w.depends + 3], "    magrittr,")
+  expect_equal(desc_file[w.depends + 4], "    stats")
+  expect_equal(desc_file[w.depends + 5], "Suggests: ")
+  expect_equal(desc_file[w.depends + 6], "    ggplot3,")
+  expect_equal(desc_file[w.depends + 7], "    glue,")
+  expect_equal(desc_file[w.depends + 8], "    knitr,")
+  expect_equal(desc_file[w.depends + 9], "    rmarkdown,")
+  expect_equal(desc_file[w.depends + 10], "    testthat")
+  expect_equal(desc_file[w.depends + 11], "LinkingTo:" )
+  expect_equal(desc_file[w.depends + 12], "    Rcpp")
+
+
+  # Clean after
+  unlink(dummypackage, recursive = TRUE)
+})
